@@ -246,7 +246,7 @@ void Manage::ActionHeaderSys(Command*c)
 
 void Manage::AuthOnServer(QString user, QString pass)
 {
-    std::cout << "MANAGE AUTH ON SERV" << std::endl;
+//    std::cout << "MANAGE AUTH ON SERV" << std::endl;
     if (!this->isConnect)
     {
         Command *C = new Command;
@@ -264,7 +264,7 @@ void Manage::AuthOnServer(QString user, QString pass)
         C->sy = s;
         C->setSize(sizeof(command) + sizeof(sys));
         emit(sendData(C->ConvertToAnswer(), C->getSize()));
-        std::cout << "SENDING AUTH DATA ON SERV" << std::endl;
+//        std::cout << "SENDING AUTH DATA ON SERV" << std::endl;
     }
     else
         this->StartSync();
@@ -278,7 +278,7 @@ void Manage::SysAskConnection(Command *c)
         {
             this->isConnect = true;
             this->username = c->sy->username;
-            std::cout << "AUTH OK"<< std::endl;
+//            std::cout << "AUTH OK"<< std::endl;
         }
         else
             std::cout << "AUTH FAIL" << std::endl;
@@ -539,7 +539,7 @@ void    Manage::SyncContact(Command *C)
         QDateTime server = QDateTime::fromString(QString(C->c->lastup), "dd.MM.yyyy.hh.mm.ss.zzz");
         if (server > local)
         {
-            std::cout << "CHECKING CONTACT FROM SERVER" << std::endl;
+//            std::cout << "CHECKING CONTACT FROM SERVER" << std::endl;
             if (C->c->status == DEL)
                 query = "DELETE FROM contact WHERE id = '" + (*it).value("id").toString() + "'";
             else
@@ -578,13 +578,13 @@ void    Manage::SyncContact(Command *C)
 
             if ((*it).value("status").toInt() == DEL)
             {
-                std::cout << "DEL DU CONTACT LOCAL  " << std::endl;
+//                std::cout << "DEL DU CONTACT LOCAL  " << std::endl;
                 query = "DELETE FROM contact WHERE id = '" + (*it).value("id").toString() + "'";
                 C1->c->idCmd = DELCONTACT;
             }
             else
             {
-                std::cout << "UPDATE DU CONTACT SUR SERVER" << std::endl;
+//                std::cout << "UPDATE DU CONTACT SUR SERVER" << std::endl;
                 query = "UPDATE contact SET status = " + QString::number(VALID) + " WHERE id = '" + (*it).value("id").toString() + "'";
                 C1->c->idCmd = UPDATECONTACT;
             }
@@ -608,7 +608,7 @@ void    Manage::SyncEndContact(Command *)
     QList<QSqlRecord> Books = this->execQuery(query);
     QList<QSqlRecord>::iterator it = Books.begin();
     ++it;
-    std::cout << "SENDING NEW CONTACT TO SERVER" << std::endl;
+//    std::cout << "SENDING NEW CONTACT TO SERVER" << std::endl;
     while (it != Books.end())
     {
         Command *C1 = new Command;
@@ -639,7 +639,7 @@ void    Manage::SyncEndContact(Command *)
         memcpy(C1->c->birthday, (*it).value("birthday").toString().toStdString().c_str(), (*it).value("birthday").toString().size());
         memcpy(C1->c->usernamecontact, (*it).value("usernamecontact").toString().toStdString().c_str(), (*it).value("usernamecontact").toString().size());
 
-        std::cout << "SENDING CONTACT" << std::endl;
+//        std::cout << "SENDING CONTACT" << std::endl;
         emit(sendData(C1->ConvertToAnswer(), C1->getSize()));
         ++it;
     }
@@ -655,7 +655,7 @@ void    Manage::SyncAgenda(Command *C)
 {
     if (!this->isSynching)
         return ;
-    std::cout << "----------------------------------------------------------" << std::endl;
+//    std::cout << "----------------------------------------------------------" << std::endl;
     QString query = "SELECT * FROM agenda";
     QList<QSqlRecord> Books = this->execQuery(query);
     QList<QSqlRecord>::iterator it = Books.begin();
@@ -670,7 +670,7 @@ void    Manage::SyncAgenda(Command *C)
         }
         ++it;
     }
-    std::cout << "----------------------------------------------------------" << std::endl;
+//    std::cout << "----------------------------------------------------------" << std::endl;
 
     if (found)
     {
@@ -768,7 +768,7 @@ void    Manage::SyncWeather(Command *C)
 {
     if (!this->isSynching)
         return ;
-    std::cout << "----------------------------------------------------------" << std::endl;
+//    std::cout << "----------------------------------------------------------" << std::endl;
     QString query = "SELECT * FROM locationweather";
     QList<QSqlRecord> Books = this->execQuery(query);
     QList<QSqlRecord>::iterator it = Books.begin();
@@ -783,7 +783,7 @@ void    Manage::SyncWeather(Command *C)
         }
         ++it;
     }
-    std::cout << "---------------------------- WEATHER LOC ------------------------------" << std::endl;
+//    std::cout << "---------------------------- WEATHER LOC ------------------------------" << std::endl;
 
     if (found)
     {
@@ -895,7 +895,7 @@ void    Manage::SyncSetting(Command *C)
         QDateTime server = QDateTime::fromString(QString(C->se->lastup), "dd.MM.yyyy.hh.mm.ss.zzz");
         if (server > local)
         {
-            std::cout << "CHECKING INFO FROM SERVER" << std::endl;
+//            std::cout << "CHECKING INFO FROM SERVER" << std::endl;
             if (C->se->status == DEL)
                 query = "DELETE FROM infouser WHERE id = '" + (*it).value("id").toString() + "'";
             else
@@ -931,13 +931,13 @@ void    Manage::SyncSetting(Command *C)
             C1->se->visibility =  (*it).value("visibility").toInt();
             if ((*it).value("status").toInt() == DEL)
             {
-                std::cout << "DEL DU info LOCAL  " << std::endl;
+//                std::cout << "DEL DU info LOCAL  " << std::endl;
                 query = "DELETE FROM infouser WHERE id = '" + (*it).value("id").toString() + "'";
                 C1->se->idCmd = DELSETTING;
             }
             else
             {
-                std::cout << "UPDATE DU info SUR SERVER" << std::endl;
+//                std::cout << "UPDATE DU info SUR SERVER" << std::endl;
                 query = "UPDATE infouser SET status = " + QString::number(VALID) + " WHERE id = '" + (*it).value("id").toString() + "'";
                 C1->se->idCmd = UPDATESETTING;
             }
@@ -990,7 +990,7 @@ void    Manage::SyncEndSetting(Command *)
         memcpy(C1->se->lastup, (*it).value("lastup").toString().toStdString().c_str(), (*it).value("lastup").toString().size());
         memcpy(C1->se->birthday, (*it).value("birthday").toString().toStdString().c_str(), (*it).value("birthday").toString().size());
         C1->se->visibility = (*it).value("visibility").toInt();
-        std::cout << "SENDING INFO" << std::endl;
+//        std::cout << "SENDING INFO" << std::endl;
         emit(sendData(C1->ConvertToAnswer(), C1->getSize()));
         ++it;
     }
@@ -1022,21 +1022,29 @@ void    Manage::SyncEvent(Command *C)
         ++it;
     }
     std::cout << "----------------------------------------------------------" << std::endl;
+    std::cout << "ID CMD " << C->getIdCmd() << std::endl;
+    std::cout << "SIZE " << C->getSize() << std::endl;
+    std::cout << "ID HEADER " << C->getIdHeader() << std::endl;
+    std::cout << "----------------------------------------------------------" << std::endl;
+
 
     if (found)
     {
+        std::cout << "EVENT EXIST ON LOCAL BASE" << std::endl;
         QDateTime local = QDateTime::fromString((*it).value("lastup").toString(), "dd.MM.yyyy.hh.mm.ss.zzz");
         QDateTime server = QDateTime::fromString(QString(C->e->lastup), "dd.MM.yyyy.hh.mm.ss.zzz");
         if (server > local)
         {
+            std::cout << "TAKING EVENT VERSION FROM SERVER" << std::endl;
             if (C->e->status == DEL)
                 query = "DELETE FROM events WHERE id = '" + (*it).value("id").toString() + "'";
             else
-                query = "UPDATE events SET lastup = '" + QString(C->e->lastup) + "',  country = '" + QString(C->e->country) + "', city = '" + QString(C->e->city) + "', description = '" + QString(C->e->description) + "', title = '" + QString(C->e->title) + "date = '" + QString(C->e->date) + "', hour = '" + QString(C->e->hour) + "', createFName = '" + QString(C->e->createFName) + "', createLName = '"+ QString(C->e->createLName) + "', contactList = '" + QString(C->e->contactList) + "', status = " + QString::number(VALID) + " WHERE id = '" + (*it).value("id").toString() + "'";
+                query = "UPDATE events SET lastup = '" + QString(C->e->lastup) + "',  country = '" + QString(C->e->country) + "', city = '" + QString(C->e->city) + "', description = '" + QString(C->e->description) + "', title = '" + QString(C->e->title) + "', date = '" + QString(C->e->date) + "', hour = '" + QString(C->e->hour) + "', createFName = '" + QString(C->e->createFName) + "', createLName = '"+ QString(C->e->createLName) + "', contactList = '" + QString(C->e->contactList) + "', status = " + QString::number(VALID) + " WHERE id = '" + (*it).value("id").toString() + "'";
             this->execQuery(query);
         }
         else if (server < local)
         {
+            std::cout << "TAKING EVENT VERSION FROM CLIENT" << std::endl;
             Command *C1 = new Command;
             C1->e = new events;
             C1->setIdHeader(HEADEREVENT);
@@ -1081,16 +1089,21 @@ void    Manage::SyncEvent(Command *C)
         }
     }
     else
+    {
+        std::cout << "ADDING EVENT IN DATABASE" << std::endl;
         if (C->e->status != DEL)
         {
             query = "INSERT INTO events (id, lastup, country, city, description, title, date, hour, createFName, createLName, contactList, status) VALUES ('" + QString(C->e->idTime) + "','" + QString(C->e->lastup) + "','" + QString(C->e->country) + "', '" + QString(C->e->city) + "', '" + QString(C->e->description) + "', '" + QString(C->e->title) + "', '" + QString(C->e->date)+ "', '" + QString(C->e->hour)+ "', '" + QString(C->e->createFName)+ "', '" + QString(C->e->createLName)+ "', '" + QString(C->e->contactList) +  "', " + QString::number(VALID) + ");";
             this->execQuery(query);
         }
+    }
 }
 
 
 void    Manage::SyncEndEvent(Command *C)
 {
+    std::cout << "SYNC END EVENT" << std::endl;
+
     if (!this->isSynching)
         return ;
     QString query = "SELECT * FROM events WHERE status = " + QString::number(MODIF);
